import { r as registerInstance, c as createEvent, h, H as Host } from './index-996ea621.js';

const k2btEditCollectionCss = ":host{display:block}.K2BT_EditCollectionItemDelete::after{cursor:pointer}";

const K2btEditCollection = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.inputEvent = createEvent(this, "input", 7);
    this.changeEvent = createEvent(this, "change", 7);
    this.value = [];
    this.maxSelectionSize = 0;
    this.datatype = K2btEditCollection.DATATYPE_CHARACTER;
    // used only for character
    this.length = 10;
    // used only for numerics
    this.integers = 5;
    // used only for numerics
    this.decimals = 2;
    this.enabled = true;
    this.inputclass = '';
    this.readonlyclass = '';
    this.invitemessage = '';
    this.itemInputs = [];
    this._triggerChangeDebouncer = null;
  }
  removeItem(index) {
    this.value = this.value.filter((_item, i) => i != index);
    this.triggerChangeEvent();
  }
  onInput(index, _ev) {
    if (index == this.value.length && this.itemInputs[index].value !== '') {
      this.value = this.value.concat(['']);
    }
    this.value[index] = this.itemInputs[index].value;
    _ev.stopPropagation();
    this.inputEvent.emit(null);
  }
  triggerChangeEvent() {
    if (this._triggerChangeDebouncer != null)
      clearTimeout(this._triggerChangeDebouncer);
    this._triggerChangeDebouncer = setTimeout(() => {
      this.changeEvent.emit(null);
    }, 200);
  }
  render() {
    this.itemInputs = [];
    var styleObj = {};
    var maxLength = 0;
    if (this.datatype == K2btEditCollection.DATATYPE_NUMERIC) {
      //@ts-ignore
      styleObj.textAlign = 'right';
      maxLength = this.integers + this.decimals + (this.decimals > 0 ? 1 : 0);
    }
    else {
      maxLength = this.length;
    }
    //@ts-ignore
    styleObj.width = maxLength + 'ch';
    const displayedvalues = this.maxSelectionSize == 0 || this.value.length < this.maxSelectionSize ? this.value.concat(['']) : this.value;
    return (h(Host, null, h("div", { class: "K2BT_EditCollection", style: !this.enabled ? {} : { display: 'none' } }, !this.enabled
      ? this.value.map(v => (h("div", { class: "K2BT_EditCollectionItem" }, h("p", { class: "form-control-static" }, h("span", { class: !this.enabled ? this.readonlyclass : this.readonlyclass + ' gx-invisible', "data-gx-readonly": "" }, v)))))
      : ''), h("div", { class: "K2BT_EditCollection", style: this.enabled ? {} : { display: 'none' } }, displayedvalues.map((v, index) => (h("div", { class: "K2BT_EditCollectionItem" }, h("input", { class: 'form-control K2BT_EditCollectionItemInput ' + this.inputclass, type: "text", value: v, style: styleObj, maxLength: maxLength, onInput: ev => this.onInput(index, ev), ref: c => (this.itemInputs[index] = c), onChange: () => this.triggerChangeEvent(), placeholder: this.invitemessage }), h("span", { class: "K2BT_EditCollectionItemDelete", onClick: () => this.removeItem(index) })))))));
  }
};
K2btEditCollection.DATATYPE_CHARACTER = 'CHAR';
K2btEditCollection.DATATYPE_NUMERIC = 'NUMERIC';
K2btEditCollection.style = k2btEditCollectionCss;

export { K2btEditCollection as k2bt_edit_collection };
